netapp_ontap.models.qos_policy_fixed API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.qos_policy_fixed`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class QosPolicyFixedSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the QosPolicyFixed object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `capacity_shared: bool GET POST`

    Specifies whether the capacities are shared across all objects that use this QoS policy-group. Default is false.

  `max_throughput: str GET POST PATCH`

    Maximum throughput defined by this policy. It is specified in terms of Kbps, Mbps or Gbps along with or without IOPS. 0 means no maximum throughput is enforced.

    Example:

  `max_throughput_iops: Size GET POST PATCH`

    Maximum throughput defined by this policy. It is specified in terms of IOPS. 0 means no maximum throughput is enforced.

  `max_throughput_mbps: Size GET POST PATCH`

    Maximum throughput defined by this policy. It is specified in terms of Mbps. 0 means no maximum throughput is enforced.

  `min_throughput: str GET POST PATCH`

    Minimum throughput defined by this policy. It is specified in terms of Kbps, Mbps or Gbps along with or without IOPS. 0 means no minimum throughput is enforced.

    Example:

  `min_throughput_iops: Size GET POST PATCH`

    Minimum throughput defined by this policy. It is specified in terms of IOPS. 0 means no minimum throughput is enforced. These floors are not guaranteed on non-AFF platforms or when FabricPool tiering policies are set.

  `min_throughput_mbps: Size GET POST PATCH`

    Minimum throughput defined by this policy. It is specified in terms of Mbps. 0 means no minimum throughput is enforced.